%define fname		vid.stab
%define	major		1.1
%define	libname		%mklibname vidstab %{major}
%define	develname	%mklibname vidstab -d
%define staticname	%mklibname -s -d vidstab

%define gitver		git20190213

%bcond_with		use_clang

Summary:	Video stabilization library
Name:		vidstab
Version:	1.1.0
Release:	%mkrel 2
License:	GPLv2
Group:		Video
Url:		https://github.com/georgmartius/vid.stab
Source0:	%{fname}-%{version}.tar.xz
BuildRequires:	cmake
BuildRequires:	libgomp-devel
%if %{with use_clang}
BuildRequires:	clang
BuildRequires:	libomp
BuildRequires:	libomp-devel
%endif

%description
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

A video acquired using a hand-held camera or a camera mounted on a
vehicle, typically suffers from undesirable shakes and
jitters. Activities like surfing, skiing, riding and walking while
shooting videos are especially prone to erratic camera shakes. Vidstab
targets these video contents to help create smoother and stable
videos.

%package -n	%{libname}
Summary:	A video stabilization library
Group:		System/Libraries

%description -n	%{libname}
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

This package contains the shared libraries of vid.stab.

%package -n	%{develname}
Summary:	Development files for the vid.stab library
Group:		Development/Libraries
Requires:	%{libname} = %{version}-%{release}
Provides:	%{libname}-devel = %{version}-%{release}
Provides:	vidstab-devel = %{version}-%{release}

%description -n	%{develname}
A video stabilization library which can be plugged-in with ffmpeg and
Transcode.

Install this package if you want to compile apps with vid.stab support.

%package -n	%{staticname}
Summary:	Static libraries for linking to vid.stab
Group:		Development/Libraries
Requires:	%{develname} = %{version}-%{release}
Provides:	%{name}-static = %{version}-%{release}
Provides:	vistab-static-devel = %{version}-%{release}

%description -n	%{staticname}
Static libraries for vid.stab.

%prep
%setup -n %{fname}-%{version}
%apply_patches
%if %{with use_clang}
perl -pi -e 's@-lgomp@-fopenmp@g' CMakeLists.txt
perl -pi -e 's@vidstab gomp@vidstab omp@g' CMakeLists.txt
%endif

%build
%if %{with use_clang}
%global optflags %{optflags} -fopenmp
%global ldflags %{ldflags} -fopenmp
%endif

export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"

export CFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags}"

# build static libs OFF in two steps (because actually cmake doesn't shared ans static libs at the same time)
%cmake \
	-DUSE_OMP:BOOL=ON \
	-DSSE2_FOUND:BOOL=ON \
	-DSSE3_FOUND:BOOL=ON \
	-DSSE4_1_FOUND:BOOL=ON \
	-DSSSE3_FOUND:BOOL=ON \
	-DBUILD_STATIC_LIBS:BOOL=ON \
	-DBUILD_SHARED_LIBS:BOOL=OFF

%cmake_build
cp -rf %{_builddir}/vid.stab-1.1.0/build/libvidstab.a %{_builddir}/vid.stab-1.1.0/

rm -rf %{_builddir}/vid.stab-1.1.0/build/*
ccache -c

export LDFLAGS="-L/usr/lib64/libglvnd/ $LDFLAGS"

export CFLAGS="%{optflags} -fPIC"
export LDFLAGS="%{ldflags}"

cmake .. \
	-DUSE_OMP:BOOL=ON \
	-DSSE2_FOUND:BOOL=ON \
	-DSSE3_FOUND:BOOL=ON \
	-DSSE4_1_FOUND:BOOL=ON \
	-DSSSE3_FOUND:BOOL=ON \
	-DBUILD_STATIC_LIBS:BOOL=OFF \
	-DBUILD_SHARED_LIBS:BOOL=ON

%cmake_build

%install
%cmake_install
mkdir -p %{buildroot}%{_libdir}
install -m 644 libvidstab.a %{buildroot}%{_libdir}/

cp -Rf %{buildroot}/usr/local/* %{buildroot}/usr/
rm -rf %{buildroot}/usr/local

sed -i s/"\/usr\/local"/"\/usr"/g %{buildroot}%{_libdir}/pkgconfig/vidstab.pc


%files -n %{libname}
%{_libdir}/libvidstab.so.%{major}

%files -n %{develname}
%{_libdir}/libvidstab.so
%dir %{_includedir}/vid.stab
%{_includedir}/vid.stab/*.h
%{_libdir}/pkgconfig/vidstab.pc

%files -n %{staticname}
%{_libdir}/*.a



%changelog
* Thu Mar 09 2023 onkelho <oh.quait at gmail.com> - 1.1.0-2pclos2023
- new imported from mga9
